@@ -607,12 +607,10 @@ int main (int argc, char* argv[]) {
             GTK_SIGNAL_FUNC (cbPluginRemoved), app);
     gtk_paned_add1 (app->vsplit_view, app->view_base);
     app->infopanel_view = gtk_text_view_new ();
-    app->info_viewport = gtk_scrolled_window_new (0L, 0l);
-    app->html_viewport = gtk_scrolled_window_new (0L, 0l);
+    app->info_viewport = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (app->info_viewport),
             GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (app->html_viewport),
-            GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+    app->html_viewport = hildon_pannable_area_new ();
     gtk_scrolled_window_add_with_viewport
         (GTK_SCROLLED_WINDOW (app->info_viewport), app->infopanel_view);
     g_object_set (G_OBJECT (app->infopanel_view),
