@@ -29,6 +29,13 @@ KMPLAYER_NO_EXPORT Node *RSS::Rss::childFromTag (const String & tag) {
     return NULL;
 }
 
+void *RSS::Rss::role (RoleType msg, void *content)
+{
+    if (RolePlaylist == msg)
+        return NULL;
+    return Element::role (msg, content);
+}
+
 KMPLAYER_NO_EXPORT Node *RSS::Channel::childFromTag (const String & tag) {
     const char *ctag = (const char *) tag;
     if (!strcmp (ctag, "item"))
@@ -47,12 +54,15 @@ KMPLAYER_NO_EXPORT void RSS::Channel::closed () {
             title = c->innerText ().stripWhiteSpace ();
             break;
         }
-    Title::closed ();
+    Element::closed ();
 }
 
-KMPLAYER_NO_EXPORT bool RSS::Channel::expose () const {
-    return !title.isEmpty () || //return false if no caption and only one
-        previousSibling () || nextSibling ();
+void *RSS::Channel::role (RoleType msg, void *content)
+{
+    if (RolePlaylist == msg)
+        return !title.isEmpty () || //return false if no title and only one
+            previousSibling () || nextSibling () ? (PlaylistRole *) this : NULL;
+    return Element::role (msg, content);
 }
 
 KMPLAYER_NO_EXPORT Node *RSS::Item::childFromTag (const String & tag) {
@@ -102,11 +112,11 @@ KMPLAYER_NO_EXPORT void RSS::Item::closed () {
             group->addSummary (this, NULL);
         if (enclosure) {
             enclosure->setCaption (title);
-            enclosure->description = description;
+            enclosure->m_description = description;
         }
         summary_added = true;
     }
-    Title::closed ();
+    Element::closed ();
 }
 
 String RSS::Item::description () const {
@@ -116,8 +126,12 @@ String RSS::Item::description () const {
     return String ();
 }
 
+String RSS::Enclosure::description () const {
+    return m_description;
+}
+
 KDE_NO_EXPORT void RSS::Enclosure::activate () {
-    document ()->message (MsgInfoString, &description);
+    document ()->message (MsgInfoString, &m_description);
     Mrl::activate ();
 }
 
