@@ -172,6 +172,7 @@ void Control::init () {
     gst->setPlayer ("/opt/kmplayer/bin/kgstplayer");
     gst->setAudioDriver ("pulse");
     gst->setVideoDriver ("xv");
+    gst->setAutoSubTitles (true);
     media_server = gst;
     if (glob ("/usr/bin/mplayer", 0, NULL, &globbuf) != GLOB_NOMATCH) {
         MPlayer *mp = new MPlayer (this, "mplayer");
@@ -352,10 +353,21 @@ void Control::play () {
     if (!playlist_data->document)                // nothing to play
         return;
     if (playlist_data->document->active ()) {    // is playing
-        if (playlist_data->document->state == Node::state_deferred)
+        Mrl *cur_item_playing = m_process->mrl ();
+        if (!m_process->playing () ||
+                Mrl::WindowMode == m_process->mrl ()->view_mode ||
+                cur_item_playing == playlist_data->document->mrl ())
+            cur_item_playing = NULL;
+
+        if (playlist_data->document->state == Node::state_deferred) {
             playlist_data->document->undefer (); // unpause
-        else
+            if (cur_item_playing)
+                cur_item_playing->undefer ();
+        } else {
             playlist_data->document->defer ();   // pause
+            if (cur_item_playing)
+                cur_item_playing->defer ();
+        }
     } else {
         //gtk_paned_set_position (m_app->vsplit_view, VSPLIT);
         //gtk_container_resize_children (GTK_CONTAINER (m_app->vsplit_view));
@@ -1003,10 +1015,7 @@ void KMPlayer::jump (Node *n, Control *ctr) {
             return;
         if (ctr->process ()->playing () &&
                 ctr->process ()->mrl() == mrl) {
-            if (ctr->playlist_data->document->state == Node::state_deferred)
-                ctr->playlist_data->document->undefer (); // unpause
-            else
-                ctr->playlist_data->document->defer ();   // pause
+            ctr->play (); // pause or unpause
         } else {
             //debugLog() << "jump " << mrl->src << endl;
             // FIXME: group activation doesn't work
