@@ -825,6 +825,7 @@ void cb_playlistMenuActivate (GtkWidget *, GdkEvent *, Application * app) {
         Node *node = getNode (pld, path);
         if (node) {
             show_copy = isListItem (node->id) ||
+                id_node_group_node == node->id ||
                 (pld->id == 0 &&
                  node->mrl () &&
                  node->id != id_node_playlist_document &&
@@ -862,21 +863,22 @@ void cb_playlistCopy (GtkButton * button, Application * app) {
     PlayListData * pld = getListDataFromSelection (app, &path);
     if (pld) {
         Node *node = getNode (pld, path);
-        if (node && node->mrl ()) {
+        if (node) {
             CONTROL(app)->copyPasteNode = 0L;
-            if (isListItem (node->id)) {
+            if (isListItem (node->id) || id_node_group_node == node->id) {
                 CONTROL(app)->copyPasteXml = node->outerXML (false);
-            } else {
+            } else if (node->mrl ()) {
                 TextStream txt;
                 txt << "<item url=\""
                     << XMLStringlet (node->mrl ()->src)
                     << "\"/>";
                 CONTROL(app)->copyPasteXml = txt.release ();
             }
-            gtk_clipboard_set_text (gtk_clipboard_get_for_display (
-                        gtk_widget_get_display (GTK_WIDGET (button)),
-                        GDK_SELECTION_CLIPBOARD),
-                    (const char *)node->mrl ()->src, -1);
+            if (node->mrl ())
+                gtk_clipboard_set_text (gtk_clipboard_get_for_display (
+                            gtk_widget_get_display (GTK_WIDGET (button)),
+                            GDK_SELECTION_CLIPBOARD),
+                        (const char *)node->mrl ()->src, -1);
         }
     }
 }
