@@ -398,7 +398,8 @@ MPlayer::MPlayer (ProcessNotify *ctrl, const char *nm)
    path ("mplayer"),
    audio_driver (NULL),
    video_driver (NULL),
-   wait_for_pause (false) {}
+   wait_for_pause (false),
+   auto_sub_titles (false) {}
 
 MPlayer::~MPlayer () {
 }
@@ -415,19 +416,10 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
         return false;
     }
     request_seek = NO_SEEK;
-    String wd (getenv ("HOME"));
-    URL url (m_url);
-    is_local_file = url.isLocalFile ();
-    if (is_local_file) {
-        m_url = url.path ();
-        wd = url.path ();
-        int pos = wd.lastIndexOf (String ("/"));
-        if (pos > -1)
-            wd.truncate (pos);
-    }
     request_quit = false;
     outbuf[0] = 0;
     String cmdline (path);
+
     cmdline += " -nofs -slave -identify -vo ";
     char buf[128];
     //if (has_xv)
@@ -438,10 +430,43 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
                 ? video_driver
                 : "xv");
     cmdline += String (buf);
+
     if (audio_driver) {
         snprintf (buf, sizeof (buf), " -ao %s", audio_driver);
         cmdline += String (buf);
     }
+
+    String wd (getenv ("HOME"));
+    URL url (m_url);
+    is_local_file = url.isLocalFile ();
+    if (is_local_file) {
+        m_url = url.path ();
+        wd = url.path ();
+        int pos = wd.lastIndexOf (String ("/"));
+        if (pos > -1)
+            wd.truncate (pos);
+#if 0
+        if (auto_sub_titles) {
+            pos = m_url.lastIndexOf (String ("."));
+            if (pos > -1) {
+                String sub = m_url.left (pos + 1);
+                debugLog() << "check " << sub << endl;
+                if (File (sub + "srt").exists ())
+                    sub += "srt";
+                else if (File (sub + "SRT").exists ())
+                    sub += "SRT";
+                else
+                    sub.clear ();
+                if (!sub.isEmpty ()) {
+                    char *quoted = g_shell_quote ((const char *) sub);
+                    cmdline += String (" -sub ") + String (quoted);
+                    g_free (quoted);
+                }
+            }
+        }
+#endif
+    }
+
     snprintf (buf, sizeof(buf), " -wid %u ", m_viewer);
     cmdline += String (buf);
     Mrl *mrl = this->mrl ();
@@ -566,10 +591,12 @@ KMPLAYER_NO_EXPORT bool MPlayer::seek (int pos, bool absolute) {
     }
     if (request_seek != NO_SEEK)
         return false;
-    if (absolute && m_length > 0) {
-        pos -= m_position;
-        absolute = false;
+    if (!absolute && m_length > 0) {
+        pos += m_position;
+        absolute = true;
     }
+    if (absolute && pos < 0)
+        pos = 0;
     request_seek = pos;
     char buf[32];
     snprintf (buf, sizeof (buf), "seek %d %d", pos/10, absolute ? 2 : 0);
