@@ -185,6 +185,7 @@ public:
     void setPlayer (const char *p) { path = p; }
     void setAudioDriver (const char *ao) { audio_driver = ao; }
     void setVideoDriver (const char *vo) { video_driver = vo; }
+    void setAutoSubTitles (bool b) { auto_sub_titles = b; }
 
     // for UnixProcessListener functions
     void processExited (UnixProcess *);
@@ -198,12 +199,14 @@ private:
     String command_chunk;
     UnixProcess unix_process;
     int request_seek;
-    char outbuf[512];
     const char *path;
     const char *audio_driver;
     const char *video_driver;
     bool request_quit;
     bool wait_for_pause;
+    bool auto_sub_titles;
+    bool padding;
+    char outbuf[512];
 };
 
 #ifdef __ARMEL__
