@@ -962,6 +962,7 @@ static ConIcConnectionStatus ic_status = CON_IC_STATUS_CONNECTED;
 static GSList *ic_connect_waiters;
 static bool ic_connect_request;
 
+static
 void icConnection (ConIcConnection *conn, ConIcConnectionEvent *ev, gpointer) {
     ic_connect_request = false;
     ic_status = con_ic_connection_event_get_status (ev);
@@ -1111,6 +1112,7 @@ static gboolean curlChannelWrite (GIOChannel *src, GIOCondition c, gpointer d) {
 #endif
     curlPerformMulti ();
 }
+
 size_t CurlGetJob::headerLine( void *ptr, size_t size, size_t nmemb, void *stream) {
     IOJob *job = (IOJob *) stream;
     CurlGetJob *self = job->d;
@@ -1188,9 +1190,6 @@ void CurlGetJob::init (IOJob *job, off_t pos) {
     if (!global_init) {
         global_init = !curl_global_init (CURL_GLOBAL_ALL);
         easy_list = g_tree_new (easyCompare);
-        con_ic_connection = con_ic_connection_new ();
-        g_signal_connect (G_OBJECT (con_ic_connection), "connection-event",
-                G_CALLBACK (icConnection), NULL);
     }
     if (!multi)
         multi = curl_multi_init ();
@@ -1232,6 +1231,11 @@ void CurlGetJob::init (IOJob *job, off_t pos) {
     } else if (ic_connect_request) {
         ic_connect_waiters = g_slist_prepend (ic_connect_waiters, this);
     } else {
+        if (!con_ic_connection) {
+            con_ic_connection = con_ic_connection_new ();
+            g_signal_connect (G_OBJECT (con_ic_connection), "connection-event",
+                    G_CALLBACK (icConnection), NULL);
+        }
         ic_connect_request = true;
         if (con_ic_connection_connect (con_ic_connection,
                 CON_IC_CONNECT_FLAG_NONE)) {
